@@ -7,12 +7,12 @@ require Carp;
 require Scalar::Util;
 use File::Spec ();
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 our $LEADING_SPACE  = qr/(?:\n [ ]*)?/x;
 our $TRAILING_SPACE = qr/(?:[ ]* \n)?/x;
-our $START_TAG      = qr/{{/x;
-our $END_TAG        = qr/}}/x;
+our $START_TAG      = qr/\{\{/x;
+our $END_TAG        = qr/\}\}/x;
 
 our $START_OF_PARTIAL              = quotemeta '>';
 our $START_OF_SECTION              = quotemeta '#';
@@ -238,7 +238,8 @@ sub _find_value {
     my $value = $context;
 
     foreach my $part (@parts) {
-        if (   exists $value->{'_with'}
+        if ( ref $value eq "HASH"
+            && exists $value->{'_with'}
             && Scalar::Util::blessed($value->{'_with'})
             && $value->{'_with'}->can($part))
         {
@@ -246,6 +247,11 @@ sub _find_value {
             next;
         }
 
+	if( ref $value eq "ARRAY" ) {
+		$value = $value->[$part];
+		next;
+	}
+
         if (   exists $value->{'.'}
             && Scalar::Util::blessed($value->{'.'})
             && $value->{'.'}->can($part))
@@ -719,6 +725,8 @@ Yves Chevallier
 
 Ovidiu Stateina
 
+Fernando Oliveira
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2011-2015, Viacheslav Tykhanovskyi
